@@ -190,7 +190,7 @@ class SlashCommandHandler(utils.Cog):
             description = f"The {arg.name} that you want to use for the {command.qualified_name} command."
             try:
                 description = command.argument_descriptions[index] or description
-            except IndexError:
+            except (AttributeError, IndexError):
                 pass
 
             # Add option
@@ -281,10 +281,11 @@ class SlashCommandHandler(utils.Cog):
                         io.StringIO(json.dumps([i.to_json() for i in commands_to_add], indent=4)),
                         filename="slash_commands.json",
                     )
-                    await ctx.send(file=file)
+                    error_text = await e.response.json()
+                    await ctx.send(f"```json\n{json.dmups(error_text, indent=4)}```", file=file)
                 except discord.HTTPException:
                     pass
-                raise
+                return
 
         # And we done
         await ctx.reply("Done.", embeddify=False)
