@@ -61,6 +61,9 @@ def get_prefix(bot, message: discord.Message):
 
     # Make it slightly more case insensitive
     prefix.extend([i.title() for i in prefix if i])
+    prefix.extend([i.upper() for i in prefix if i])
+    prefix.extend([i.lower() for i in prefix if i])
+    prefix = list(set(prefix))  # Remove those duplicates
 
     # Add spaces for words
     possible_word_prefixes = [i for i in prefix if i and not any([o in i for o in string.punctuation])]
@@ -83,6 +86,39 @@ class RouteV8(discord.http.Route):
     BASE = 'https://discord.com/api/v8'
 
 
+_original_message = discord.Message
+_original_webhook_message = discord.WebhookMessage
+
+
+class ComponentMessage(_original_message):
+
+    __slots__ = _original_message.__slots__ + ("components",)
+
+    def __init__(self, *, state, channel, data):
+        self.components = MessageComponents.from_dict(data.get("components", list()))
+        super().__init__(state=state, channel=channel, data=data)
+
+    async def wait_for_component_interaction(self, *args, **kwargs):
+        pass
+
+    async def clear_components(self, *args, **kwargs):
+        pass
+
+    async def disable_components(self, *args, **kwargs):
+        pass
+
+    async def enable_components(self, *args, **kwargs):
+        pass
+
+    @classmethod
+    async def convert(cls, ctx, value):
+        return await commands.MessageConverter().convert(ctx, value)
+
+
+class ComponentWebhookMessage(ComponentMessage, _original_webhook_message):
+    pass
+
+
 class MinimalBot(commands.AutoShardedBot):
     """
     A minimal version of the VoxelBotUtils bot that inherits from :class:`discord.ext.commands.AutoShardedBot`
@@ -111,17 +147,37 @@ class MinimalBot(commands.AutoShardedBot):
         async def clear_components_msg_prop(message):
             return await message.edit(components=None)
 
+        async def disable_components_msg_prop(message):
+            return await message.edit(components=message.components.disable_components())
+
+        async def enable_components_msg_prop(message):
+            return await message.edit(components=message.components.enable_components())
+
         Messageable.send = send_button_msg_prop
-        discord.Message.add_reactions = add_reactions_prop
-        discord.Message.edit = edit_button_msg_prop
-        discord.Message.wait_for_button_click = wait_for_button_prop
-        discord.Message.clear_components = clear_components_msg_prop
-        discord.WebhookMessage.edit = edit_button_msg_prop
-        discord.WebhookMessage.wait_for_button_click = wait_for_button_prop
-        discord.WebhookMessage.clear_components = clear_components_msg_prop
         discord.message.MessageFlags.ephemeral = discord.flags.flag_value(lambda _: 64)
         discord.message.MessageFlags.VALID_FLAGS.update({"ephemeral": 64})
 
+        discord.Message.add_reactions = add_reactions_prop
+
+        discord.Message.edit = edit_button_msg_prop
+        discord.Message.wait_for_button_click = wait_for_button_prop  # deprecated
+        discord.Message.wait_for_component_interaction = wait_for_button_prop  # deprecated
+        discord.Message.clear_components = clear_components_msg_prop
+        discord.Message.disable_components = disable_components_msg_prop
+        discord.Message.enable_components = enable_components_msg_prop
+
+        discord.WebhookMessage.edit = edit_button_msg_prop
+        discord.WebhookMessage.wait_for_button_click = wait_for_button_prop  # deprecated
+        discord.WebhookMessage.wait_for_component_interaction = wait_for_button_prop  # deprecated
+        discord.WebhookMessage.clear_components = clear_components_msg_prop
+        discord.WebhookMessage.disable_components = disable_components_msg_prop
+        discord.WebhookMessage.enable_components = enable_components_msg_prop
+
+        discord.PartialMessage.edit = edit_button_msg_prop
+
+        # discord.Message = ComponentMessage
+        # discord.WebhookMessage = ComponentWebhookMessage
+
     async def create_message_log(
             self, messages: typing.Union[typing.List[discord.Message], discord.iterators.HistoryIterator]) -> str:
         """
@@ -343,7 +399,8 @@ class MinimalBot(commands.AutoShardedBot):
             reference: discord.MessageReference = None, mention_author: bool = None,
             components: MessageComponents = None,
             ephemeral: bool = False, embeddify: bool = None,
-            image_url: bool = None, embeddify_file: bool = True):
+            image_url: bool = None, embeddify_file: bool = True,
+            wait: bool = True):
         """
         An alternative send method so that we can add components to messages.
 
@@ -353,7 +410,7 @@ class MinimalBot(commands.AutoShardedBot):
         # Work out where we want to send to
         channel = await messageable._get_channel()
         content, embed = self.get_context_message(
-            channel, content=content, embed=embed, file=file, embeddify=embeddify,
+            messageable, content=content, embed=embed, file=file, embeddify=embeddify,
             image_url=image_url, embeddify_file=embeddify_file,
         )
         state = self._connection
@@ -376,23 +433,23 @@ class MinimalBot(commands.AutoShardedBot):
 
         # Work out our message references
         if mention_author is not None:
-            allowed_mentions = allowed_mentions or AllowedMentions().to_dict()
+            allowed_mentions = allowed_mentions or discord.AllowedMentions().to_dict()
             allowed_mentions['replied_user'] = bool(mention_author)
         if reference is not None:
             try:
                 reference = reference.to_message_reference_dict()
             except AttributeError:
-                raise InvalidArgument('reference parameter must be Message or MessageReference') from None
+                raise discord.InvalidArgument('reference parameter must be Message or MessageReference') from None
 
         # Make sure the files are valid
         if file is not None and files is not None:
-            raise InvalidArgument('cannot pass both file and files parameter to send()')
+            raise discord.InvalidArgument('cannot pass both file and files parameter to send()')
         if file:
             files = [file]
         if files and len(files) > 10:
-            raise InvalidArgument('files parameter must be a list of up to 10 elements')
+            raise discord.InvalidArgument('files parameter must be a list of up to 10 elements')
         elif files and not all(isinstance(file, discord.File) for file in files):
-            raise InvalidArgument('files parameter must be a list of File')
+            raise discord.InvalidArgument('files parameter must be a list of File')
 
         # Fix up the components
         if components:
@@ -400,23 +457,37 @@ class MinimalBot(commands.AutoShardedBot):
                 raise TypeError(f"Components kwarg must be of type {MessageComponents}")
             components = components.to_dict()
 
-        # Get our playload data
+        # Send a response if it's an interaction
         if isinstance(channel, (list, tuple)):
-            if not messageable._sent_ack_response:  # Sent no responses - send an ack
+
+            # Sent no responses - send an ack
+            if not messageable._sent_ack_response and wait:
                 await messageable.ack(ephemeral=ephemeral)
-            if messageable.ACK_IS_EDITABLE and messageable._sent_ack_response and not messageable._sent_message_response:  # Sent an ack that we should edit
+
+            # Sent no responses but we don't want a message object back from Discord
+            elif not messageable._sent_ack_response:
+                r = discord.http.Route('POST', '/interactions/{interaction_id}/{token}/callback', interaction_id=channel[0], token=channel[2])
+
+            # Sent an ack that we should edit
+            if wait and messageable.ACK_IS_EDITABLE and messageable._sent_ack_response and not messageable._sent_message_response:
                 r = discord.http.Route('PATCH', '/webhooks/{app_id}/{token}/messages/@original', app_id=channel[1], token=channel[2])
-            else:  # Sent an ack and a response, or sent an ack with no editable original message
+
+            # Sent an ack and a response, or sent an ack with no editable original message
+            elif wait:
                 r = discord.http.Route('POST', '/webhooks/{app_id}/{token}', app_id=channel[1], token=channel[2])
+
+        # Send a response if it's a channel
         else:
             r = discord.http.Route('POST', '/channels/{channel_id}/messages', channel_id=channel.id)
+
+        # Build a payload to send
         payload = {}
         if content:
             payload['content'] = content
         if tts:
             payload['tts'] = True
         if embed:
-            if r.path.startswith('/webhooks'):
+            if r.path.startswith('/webhooks') or r.path.startswith('/interactions'):
                 payload['embeds'] = [embed]
             else:
                 payload['embed'] = embed
@@ -459,11 +530,11 @@ class MinimalBot(commands.AutoShardedBot):
                 for f in files:
                     f.close()
         else:
-            # if getattr(messageable, "_sent_ack_response", True):
-            #     response_data = await self.http.request(r, json=payload)
-            # else:
-            #     response_data = await self.http.request(r, json={"type": 4, "data": payload})
+            if wait is False:
+                payload = {"type": 4, "data": payload.copy()}
             response_data = await self.http.request(r, json=payload)
+
+        # Set the attributes for the interactions
         try:
             messageable._sent_ack_response = True
         except AttributeError:
@@ -473,6 +544,10 @@ class MinimalBot(commands.AutoShardedBot):
         except AttributeError:
             pass
 
+        # See if we want to respond with anything
+        if wait is False:
+            return
+
         # Make the message object
         if isinstance(channel, (list, tuple)):
             webhook = discord.Webhook.partial(channel[1], channel[2], adapter=discord.AsyncWebhookAdapter(session=self.session))
@@ -597,7 +672,7 @@ class MinimalBot(commands.AutoShardedBot):
             check = lambda payload: original_check(payload) and message_check(payload)
         else:
             check = message_check
-        return await self.wait_for("button_click", check=check, timeout=timeout)
+        return await self.wait_for("component_interaction", check=check, timeout=timeout)
 
 
 class Bot(MinimalBot):
@@ -826,7 +901,7 @@ class Bot(MinimalBot):
             return None
 
     def get_invite_link(
-            self, *, base: str = None, client_id: int = None, scope: str = 'bot',
+            self, *, base: str = None, client_id: int = None, scope: str = None,
             response_type: str = None, redirect_uri: str = None,
             guild_id: int = None, permissions: discord.Permissions = None,
             enabled: bool = None) -> str:
@@ -862,7 +937,7 @@ class Bot(MinimalBot):
         # Make the params for the url
         data = {
             'client_id': client_id or self.config.get('oauth', {}).get('client_id', None) or self.user.id,
-            'scope': scope,
+            'scope': scope or self.config.get('oauth', {}).get('scope', None) or 'bot',
             'permissions': permissions.value,
         }
         if redirect_uri:
@@ -1093,7 +1168,11 @@ class Bot(MinimalBot):
                 pool.append(safe_data.copy())
         if not pool:
             return
-        embed.set_footer(**random.choice(pool), icon_url=self.user.avatar_url)
+        try:
+            avatar_url = self.user.avatar_url
+        except AttributeError:
+            avatar_url = embed.Empty
+        embed.set_footer(**random.choice(pool), icon_url=avatar_url)
 
     @property
     def clean_prefix(self):
