@@ -130,8 +130,8 @@ class SettingsMenuOption(object):
         try:
             if reactions:
                 user_message = None
-                check = lambda p: p.message_id == bot_message.id and p.user_id == self.context.author.id and str(r.emoji) in reactions
-                reaction, _ = await self.context.bot.wait_for("raw_reaction_add", timeout=120, check=check)
+                check = lambda p: p.message_id == bot_message.id and p.user_id == self.context.author.id and str(p.emoji) in reactions
+                reaction = await self.context.bot.wait_for("raw_reaction_add", timeout=120, check=check)
                 content = str(reaction.emoji)
             else:
                 check = lambda m: m.channel.id == self.context.channel.id and m.author.id == self.context.author.id
@@ -417,7 +417,8 @@ class SettingsMenuOption(object):
     @staticmethod
     def get_set_iterable_add_callback(
             table_name: str, column_name: str, cache_key: str, database_key: str,
-            serialize_function: typing.Callable[[typing.Any], str] = None) -> typing.Callable[['SettingsMenu', commands.Context], None]:
+            serialize_function: typing.Callable[[typing.Any], str] = None,
+            original_data_type: type = None) -> typing.Callable[['SettingsMenu', commands.Context], None]:
         """
         Return an async method that takes the data retuend by `convert_prompted_information` and then
         saves it into the database - should be used for the SettingsMenu init. This particular iterable
@@ -470,6 +471,10 @@ class SettingsMenuOption(object):
                         ctx.guild.id, role.id, database_key, value
                     )
 
+                # Set the original value for the cache
+                if original_data_type is not None:
+                    ctx.bot.guild_settings[ctx.guild.id].setdefault(cache_key, original_data_type())
+
                 # Cache the converted value
                 if value:
                     ctx.bot.guild_settings[ctx.guild.id][cache_key][role.id] = serialize_function(original_value)
@@ -757,6 +762,7 @@ class SettingsMenuIterable(SettingsMenu):
             cache_key=cache_key,
             database_key=database_key,
             serialize_function=str if len(self.converters) == 1 else self.converters[1].serialize,
+            original_data_type=list if len(self.converters) == 1 else dict,
         )
         # This default returns an async function which takes the content of the converted values which adds to the db.
         # Callable[
