@@ -7,6 +7,8 @@ default_prefix = "!"  # The prefix for the bot's commands
 support_guild_id = 0  # The ID for the support guild - used by `Bot.fetch_support_guild()`
 bot_support_role_id = 0  # The ID used to determine whether or not the user is part of the bot's support team - used for `.checks.is_bot_support()` check
 guild_settings_prefix_column = "prefix"  # Used if multiple bots connect to the same database and need to seperate their prefixes
+cached_messages = 1000  # The number of messages to cache within the bot
+ephemeral_error_messages = true  # Whether or not error messages [from slash commands] should be ephemeral
 
 # Event webhook information - some of the events (noted) will be sent to the specified url
 [event_webhook]
@@ -54,13 +56,22 @@ guild_settings_prefix_column = "prefix"  # Used if multiple bots connect to the
     guild_invite = ""  # A link to be used on !support
     github_link = ""  # A link to be used on !git
     donate_link = ""  # A link to be used on !donate
-    invite_command_permissions = []  # args here are passed directly to discord.Permissions. An empty list disabled the invite command
-    echo_command_enabled = true  # Whether or not the invite command is enabled
+    echo_command_enabled = true  # Whether or not the echo command is enabled
     stats_command_enabled = true  # Whether or not the stats command is enabled
     vote_command_enabled = false  # Whether or not the top.gg vote command is enabled
     updates_channel_id = 0  # The ID of the news channel for the bot
     info = ""  # The text passed out with the !info command
 
+# Used to generate the invite link
+[oauth]
+    enabled = false  # Whether or not an invite link is enabled via the !invite command
+    base = ""  # The base url
+    response_type = ""  # The response type given to the redirect URI
+    redirect_uri = ""  # Where the user should be redirected to upon authorizing
+    client_id = ""  #  If not set then will use the bot's ID, which is correct as of around 2017 I think
+    scope = "bot"  # The scope that will be generated with the invite link, space seperated (applications.commands for slash)
+    permissions = []  # args here are passed directly to discord.Permissions as True
+
 # This data is passed directly over to asyncpg.connect()
 [database]
     enabled = false
@@ -101,16 +112,10 @@ guild_settings_prefix_column = "prefix"  # Used if multiple bots connect to the
         twitch_client_id = ""  # Your client ID - https://dev.twitch.tv/console/apps
         twitch_client_secret = ""  # Your client secret
 
-# Used to generate the invite link - if not set then will use the bot's ID, which is correct more often than not
-[oauth]
-    client_id = ""
-
 # UpgradeChat API key data - https://upgrade.chat/developers
 [upgrade_chat]
     client_id = ""
     client_secret = ""
-    [upgrade_chat.roles]
-        "Role Name" = 0  # (role id)
 
 # Statsd analytics port using the aiodogstatsd package
 [statsd]
